@@ -215,6 +215,7 @@ def upload_data_v2(dataset_chunks: List[List[Any]], job_id: int, access_token: s
     :rtype: [type]
     """
     headers = {"Authorization": f"Bearer {access_token}"}
+
     task_url = urllib.parse.urljoin(os.environ['API_URL'], job_id)
     errors = []
     for dataset in dataset_chunks:
@@ -261,7 +262,7 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
     return upload_data_v2(dataset_chunks, job_id, access_token)
 
 
-def s3push(file_path: str, job_id: int, access_token: str):
+def push_v2(file_path: str, job_id: int, access_token: str):
     """
     Push an untagged dataset to tog.
 
@@ -271,10 +272,9 @@ def s3push(file_path: str, job_id: int, access_token: str):
     :type job_id: int
     """
     _, extension = os.path.splitext(file_path)
-    if extension == "csv":
-        push_csv2tog(job_id, file_path, access_token)
-    else:
+    if extension != "csv":
         raise ValueError("Expected file extension to be a csv.")
+    return push_csv2tog(job_id, file_path, access_token)
 
 
 def main():
